Index: third_party/pylint/checkers/__init__.py |
diff --git a/third_party/pylint/checkers/__init__.py b/third_party/pylint/checkers/__init__.py |
index 693a5ff477ed538f23f01140fef9eb8618c3f6a6..969066b5b90a7ff0a5d34b7f7b72364c6b759233 100644 |
--- a/third_party/pylint/checkers/__init__.py |
+++ b/third_party/pylint/checkers/__init__.py |
@@ -1,4 +1,4 @@ |
-# Copyright (c) 2003-2013 LOGILAB S.A. (Paris, FRANCE). |
+# Copyright (c) 2003-2010 LOGILAB S.A. (Paris, FRANCE). |
# http://www.logilab.fr/ -- mailto:contact@logilab.fr |
# |
# This program is free software; you can redistribute it and/or modify it under |
@@ -12,7 +12,7 @@ |
# |
# You should have received a copy of the GNU General Public License along with |
# this program; if not, write to the Free Software Foundation, Inc., |
-# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA. |
+# 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. |
"""utilities methods and classes for checkers |
Base id of standard checkers (used in msg and report ids): |
@@ -29,8 +29,7 @@ Base id of standard checkers (used in msg and report ids): |
11: typecheck |
12: logging |
13: string_format |
-14: string_constant |
-15-50: not yet used: reserved for future internal checkers. |
+14-50: not yet used: reserved for future internal checkers. |
51-99: perhaps used: reserved for external checkers |
The raw_metrics checker has no number associated since it doesn't emit any |
@@ -38,14 +37,14 @@ messages nor reports. XXX not true, emit a 07 report ! |
""" |
-import sys |
import tokenize |
-import warnings |
+from os import listdir |
+from os.path import dirname, join, isdir, splitext |
+from logilab.astng.utils import ASTWalker |
from logilab.common.configuration import OptionsProviderMixIn |
-from pylint.reporters import diff_string |
-from pylint.utils import register_plugins |
+from pylint.reporters import diff_string, EmptyReport |
def table_lines_from_stats(stats, old_stats, columns): |
"""get values listed in <columns> from <stats> and <old_stats>, |
@@ -68,7 +67,7 @@ def table_lines_from_stats(stats, old_stats, columns): |
return lines |
-class BaseChecker(OptionsProviderMixIn): |
+class BaseChecker(OptionsProviderMixIn, ASTWalker): |
"""base class for checkers""" |
# checker name (you may reuse an existing one) |
name = None |
@@ -86,14 +85,22 @@ class BaseChecker(OptionsProviderMixIn): |
linter is an object implementing ILinter |
""" |
+ ASTWalker.__init__(self, self) |
self.name = self.name.lower() |
OptionsProviderMixIn.__init__(self) |
self.linter = linter |
+ # messages that are active for the current check |
+ self.active_msgs = set() |
def add_message(self, msg_id, line=None, node=None, args=None): |
"""add a message of a given type""" |
self.linter.add_message(msg_id, line, node, args) |
+ def package_dir(self): |
+ """return the base directory for the analysed package""" |
+ return dirname(self.linter.base_file) |
+ |
+ |
# dummy methods implementing the IChecker interface |
def open(self): |
@@ -102,7 +109,6 @@ class BaseChecker(OptionsProviderMixIn): |
def close(self): |
"""called after visiting project (i.e set of modules)""" |
- |
class BaseRawChecker(BaseChecker): |
"""base class for raw checkers""" |
@@ -113,31 +119,45 @@ class BaseRawChecker(BaseChecker): |
stream must implement the readline method |
""" |
- warnings.warn("Modules that need access to the tokens should " |
- "use the ITokenChecker interface.", |
- DeprecationWarning) |
stream = node.file_stream |
- stream.seek(0) # XXX may be removed with astroid > 0.23 |
- if sys.version_info <= (3, 0): |
- self.process_tokens(tokenize.generate_tokens(stream.readline)) |
- else: |
- self.process_tokens(tokenize.tokenize(stream.readline)) |
+ stream.seek(0) # XXX may be removed with astng > 0.23 |
+ self.process_tokens(tokenize.generate_tokens(stream.readline)) |
def process_tokens(self, tokens): |
"""should be overridden by subclasses""" |
raise NotImplementedError() |
-class BaseTokenChecker(BaseChecker): |
- """Base class for checkers that want to have access to the token stream.""" |
- |
- def process_tokens(self, tokens): |
- """Should be overridden by subclasses.""" |
- raise NotImplementedError() |
- |
+PY_EXTS = ('.py', '.pyc', '.pyo', '.pyw', '.so', '.dll') |
def initialize(linter): |
"""initialize linter with checkers in this package """ |
- register_plugins(linter, __path__[0]) |
+ package_load(linter, __path__[0]) |
-__all__ = ('BaseChecker', 'initialize') |
+def package_load(linter, directory): |
+ """load all module and package in the given directory, looking for a |
+ 'register' function in each one, used to register pylint checkers |
+ """ |
+ globs = globals() |
+ imported = {} |
+ for filename in listdir(directory): |
+ basename, extension = splitext(filename) |
+ if basename in imported or basename == '__pycache__': |
+ continue |
+ if extension in PY_EXTS and basename != '__init__' or ( |
+ not extension and basename != 'CVS' and |
+ isdir(join(directory, basename))): |
+ try: |
+ module = __import__(basename, globs, globs, None) |
+ except ValueError: |
+ # empty module name (usually emacs auto-save files) |
+ continue |
+ except ImportError, exc: |
+ import sys |
+ print >> sys.stderr, "Problem importing module %s: %s" % (filename, exc) |
+ else: |
+ if hasattr(module, 'register'): |
+ module.register(linter) |
+ imported[basename] = 1 |
+ |
+__all__ = ('CheckerHandler', 'BaseChecker', 'initialize', 'package_load') |